local AddonName, a = ...
local AddonTitle = select(2, GetAddOnInfo(AddonName))
local PlainAddonTitle = AddonTitle:gsub("|c........", ""):gsub("|r", "")
local L = a.Localize
local s = SpellFlashAddon
local CheckButtonOptions = nil

local parent = AddonName.."_SpellFlashAddonOptionsFrame"
a.OptionsFrame = CreateFrame("Frame", parent, nil, "SpellFlashAddon_OptionsFrameTemplate2")

function a.print(...)
	print("|cFF00FFFF["..PlainAddonTitle.."]|r", ...)
end

function a.OptionsFrame.okay()
	s.SetModuleConfig(AddonName, "spell_flashing_off", not _G[parent.."_SpellFlashing"]:GetChecked())
	if type(CheckButtonOptions) == "table" then
		for button, options in pairs(CheckButtonOptions) do
			if _G[parent..button] and type(options) == "table" then
				if type(options.ConfigKey) == "string" and options.ConfigKey ~= "" and options.ConfigKey ~= "My_Config_Key" then
					if options.DefaultChecked then
						s.SetModuleConfig(AddonName, options.ConfigKey, not _G[parent..button]:GetChecked())
					else
						s.SetModuleConfig(AddonName, options.ConfigKey, not not _G[parent..button]:GetChecked())
					end
				end
			end
		end
	end
	if type(a.Spam) == "table" and type(a.Spam[1]) == "table" and type(a.Spam[1].Function) == "function" then
		local Value = _G[parent.."_ScriptSlider"]:GetValue()
		if Value == 1 or type(a.Spam[Value]) ~= "table" or type(a.Spam[Value].Function) ~= "function" then
			Value = nil
		end
		s.SetModuleConfig(AddonName, "script_number", Value)
	end
end

function a.OptionsFrame.refresh()
	_G[parent.."_SpellFlashing"]:SetChecked(not s.GetModuleConfig(AddonName, "spell_flashing_off"))
	if type(CheckButtonOptions) == "table" then
		for button, options in pairs(CheckButtonOptions) do
			if _G[parent..button] and type(options) == "table" then
				if type(options.ConfigKey) == "string" and options.ConfigKey ~= "" and options.ConfigKey ~= "My_Config_Key" then
					if options.DefaultChecked then
						_G[parent..button]:SetChecked(not s.GetModuleConfig(AddonName, options.ConfigKey))
					else
						_G[parent..button]:SetChecked(s.GetModuleConfig(AddonName, options.ConfigKey))
					end
					_G[parent..button.."Text"]:SetText(options.Label or "")
					_G[parent..button]:Show()
				end
			end
		end
	end
	if type(a.Spam) == "table" and type(a.Spam[1]) == "table" and type(a.Spam[1].Function) == "function" then
		_G[parent.."_ScriptSlider"]:Show()
		_G[parent.."_ScriptSliderTitle"]:Show()
		_G[parent.."_ScriptSliderDescription"]:Show()
		_G[parent.."_ScriptSliderMinValue"]:Show()
		_G[parent.."_ScriptSliderMaxValue"]:Show()
		_G[parent.."_ScriptSliderValue"]:Show()
		local MaxValue = getn(a.Spam)
		_G[parent.."_ScriptSlider"]:SetMinMaxValues(1, MaxValue)
		_G[parent.."_ScriptSliderMinValueLabel"]:SetText("1")
		_G[parent.."_ScriptSliderMaxValueLabel"]:SetText(""..MaxValue)
		local Value = s.GetModuleConfig(AddonName, "script_number") or 1
		if type(a.Spam[Value]) ~= "table" or type(a.Spam[Value].Function) ~= "function" then
			Value = 1
		end
		_G[parent.."_ScriptSlider"]:SetValue(Value)
		_G[parent.."_ScriptSliderTitleLabel"]:SetText(a.Spam[Value].Title or "")
		_G[parent.."_ScriptSliderDescriptionLabel"]:SetText(a.Spam[Value].Description or "")
		_G[parent.."_ScriptSliderValueLabel"]:SetText(""..Value)
	end
end

function a.OptionsFrame.default()
	s.ClearAllModuleConfigs(AddonName)
end

L["Spell Flashing"] = s.L["Spell Flashing"]
local function LocalizeFontStrings(frame)
	for _, f in next, {frame:GetChildren()} do
		if f:GetObjectType() == "FontString" then
			f:SetText(L[f:GetText()])
		else
			for _, f in next, {f:GetRegions()} do
				if f:GetObjectType() == "FontString" then
					f:SetText(L[f:GetText()])
				end
			end
		end
	end
end
LocalizeFontStrings(a.OptionsFrame)
_G[parent.."TitleString"]:SetText(AddonTitle.." "..GetAddOnMetadata(AddonName, "Version"))

function a.OptionsFrame.UpdateSliderText(self)
	if self and self:IsVisible() then
		local Value = self:GetValue()
		if type(a.Spam[Value]) ~= "table" or type(a.Spam[Value].Function) ~= "function" then
			Value = 1
		end
		_G[parent.."_ScriptSliderTitleLabel"]:SetText(a.Spam[Value].Title or "")
		_G[parent.."_ScriptSliderDescriptionLabel"]:SetText(a.Spam[Value].Description or "")
		_G[parent.."_ScriptSliderValueLabel"]:SetText(""..Value)
	end
end

function a.RunSpamTable()
	if type(a.Spam) == "table" then
		local i = s.GetModuleConfig(AddonName, "script_number") or 1
		if type(a.Spam[i]) == "table" and type(a.Spam[i].Function) == "function" then
			a.Spam[i].Function()
		elseif type(a.Spam[1]) == "table" and type(a.Spam[1].Function) == "function" then
			s.SetModuleConfig(AddonName, "script_number", nil)
			a.Spam[1].Function()
		end
	end
end

function a.LoadConfigs(config)
	if type(config) == "table" then
		s.RegisterOtherAurasFunction(config.OtherAurasFunction)
		if type(config.event) == "table" and next(config.event) then
			if not a.OptionsFrame.OnEvent then
				function a.OptionsFrame.OnEvent(self, event, ...)
					config.event[event](event, ...)
				end
				a.OptionsFrame:SetScript("OnEvent", a.OptionsFrame.OnEvent)
			end
			for event in pairs(config.event) do
				a.OptionsFrame:RegisterEvent(event)
			end
		end
		if type(config.CheckButtonOptions) == "table" then
			CheckButtonOptions = config.CheckButtonOptions
		end
		if type(config.SlashHandler) == "function" then
			SlashCmdList[AddonName] = config.SlashHandler
		end
		if type(config.SlashCommands) == "table" then
			for i, v in ipairs(config.SlashCommands) do
				_G["SLASH_"..AddonName..i] = v
			end
		end
	end
end

L["<SPELL> has not been defined in a function!"] = s.L["<SPELL> has not been defined in a function!"]
local function False() return false end
local function DefaultCastable(_, key) a.print(s.Replace(L["<SPELL> has not been defined in a function!"], "<SPELL>", "\""..key.."\"")) return False end
a.Castable = setmetatable({}, {__index = DefaultCastable})
a.VehicleCastable = setmetatable({}, {__index = DefaultCastable})
a.ItemCastable = setmetatable({}, {__index = DefaultCastable})

a.OptionsFrame.parent = select(2, GetAddOnInfo("SpellFlash"))
a.OptionsFrame.name = AddonTitle
InterfaceOptions_AddCategory(a.OptionsFrame)

